#ifndef AMRMIXER_H
#define AMRMIXER_H

#ifdef HAVE_LIBASOUND
#include <alsa/asoundlib.h>
#else
#include <linux/soundcard.h>
#endif

#define MAX_NUM_MIXER_DEVS  20
#define MAX_MIXER_VALUE     100

struct mix_channel
{
  char *label;               /* the channel's name */

  int left;                  /* device values */
  int right;
  int stereo;
  int dev_num;
  int dev_bit;
  int rec_src;
  int rec_support;

  int solo_channel;          /* solo enabled channel ? */

#ifdef HAVE_LIBASOUND
  snd_mixer_elem_t *elem; 
#else
  int muted_l;               /* saved muted values */
  int muted_r;
#endif
};


struct mixer
{
  void (*dispose)(struct mixer *mix);
  void (*mute)(struct mixer *mix,int channel);
  void (*unmute)(struct mixer *mix,int channel);
  void (*togglemute)(struct mixer *mix,int channel);
  int (*getmute)(struct mixer *mix,int channel);
  void (*solo)(struct mixer *mix,int channel);
  void (*record)(struct mixer *mix,int channel);
  void (*getvolume)(struct mixer *mix,int channel,int *left,int *right);
  void (*setvolume)(struct mixer *mix,int channel,int left,int right);
  void (*incvolume)(struct mixer *mix,int channel,int left,int right);
  void (*decvolume)(struct mixer *mix,int channel,int left,int right);
  char *(*getchannelname)(struct mixer *mix,int channel);
  int (*getchanneldev)(struct mixer *mix,int channel);
#ifdef HAVE_LIBASOUND
  snd_ctl_card_info_t *hw_info;
  snd_mixer_t *handle;
#else
  struct mixer_info info;
  int handle;
  int devmask;
  int stereomask;
  int recmask;
  int recsrc;
#endif
  int devs;
  int rec_devs;
  int stereo_devs;
  struct mix_channel channel[MAX_NUM_MIXER_DEVS];
};

struct mixer *mixer_create(char *device);

#endif
